@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -688,7 +688,7 @@ void intx( long double el1, long double el2, long double b,
 	  nt=0;
 	  if( ns >= nma)
 		fprintf( stderr,
-			"\nxnec2c: step size limited at z= %10.5LF", z );
+			"xnec2c: step size limited at z= %10.5LF\n", z );
 	  else
 	  {
 		/* halve step size */
@@ -855,8 +855,8 @@ sbf( int i, int is, long double *aa, long double *bb, long double *cc )
 		  if( jcox == 0 )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: sbf() - segment connection"
-				" error for segment %d", i );
+				"xnec2c: sbf() - segment connection"
+				" error for segment %d\n", i );
 			stop( "Segment connection error", 1 );
 		  }
 		  else
@@ -1066,8 +1066,8 @@ tbf( int i, int icap )
 		  else
 		  {
 			fprintf( stderr,
-				"\nxnec2c: tbf() - segment connection"
-				" error for segment %5d", i );
+				"xnec2c: tbf() - segment connection"
+				" error for segment %5d\n", i );
 			stop( "Segment connection error", 1 );
 		  }
 		}
@@ -1315,8 +1315,8 @@ trio( int j )
 	  if( jcox == 0 )
 	  {
 		fprintf( stderr,
-			"\nxnec2c: trio() - segment connention"
-			" error for segment %5d", j );
+			"xnec2c: trio() - segment connention"
+			" error for segment %5d\n", j );
 		stop( "Segment connention error", 1 );
 	  }
 	  else
