@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -109,9 +109,6 @@ static GtkWidget *open_dialog = NULL;
 GtkWidget *animate_dialog = NULL;
 extern GtkWidget *error_dialog;
 
-/* About dialog widget */
-static GtkWidget *aboutdialog = NULL;
-
 /* Animation timeout callback tag */
 gint anim_tag = -1;
 
@@ -172,8 +169,7 @@ extern near_field_t near_field;
 /* Action flag for NEC2 "card" editors */
 static int action = EDITOR_NEW;
 
-/* Number of forked child processes & forked flag */
-extern int nchild;
+/* Process Forked flag */
 extern gboolean FORKED;
 
 /* Commands between parent and child processes */
@@ -203,7 +199,7 @@ on_main_window_delete_event            (GtkWidget       *widget,
 
   void
 on_new_activate     	              (GtkMenuItem     *menuitem,
-										gpointer         user_data)
+									  gpointer         user_data)
 {
   if( nec2_edit_window == NULL )
   {
@@ -270,17 +266,18 @@ on_main_save_activate        (GtkMenuItem     *menuitem,
   /* Make the structure image save file name from input file
    * name. The count of each image type saved is incremented */
   if( isFlagSet(DRAW_CURRENTS) )
-	sprintf( saveas, "%s-%s_%03d.%s", infile, "current", ++ccr, "png" );
+	snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "current", ++ccr, "png" );
   else
 	if( isFlagSet(DRAW_CHARGES) )
-	  sprintf( saveas, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
+	  snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
 	else
-	  sprintf( saveas, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
+	  snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
 
   saveas_pixmap = structure_pixmap;
   saveas_pixmap_width  = structure_pixmap_width;
   saveas_pixmap_height = structure_pixmap_height;
   ClearFlag( NEC2_SAVE );
+  SetFlag( IMAGE_SAVE );
 
   /* Open file selector to specify file  */
   /* name for saving the structure image */
@@ -482,18 +479,6 @@ on_common_freq_activate                (GtkMenuItem     *menuitem,
 }
 
 
-  void
-on_main_about_activate                 (GtkMenuItem     *menuitem,
-	gpointer         user_data)
-{
-  if( aboutdialog == NULL )
-  {
-	aboutdialog = create_aboutdialog();
-	gtk_widget_show( aboutdialog );
-  }
-}
-
-
   void
 on_main_x_axis_clicked                 (GtkButton       *button,
 										gpointer         user_data)
@@ -821,7 +806,7 @@ on_fileselection_response(
 	strncpy( filename, gtk_file_selection_get_filename(
 		  GTK_FILE_SELECTION(dialog)), 76 );
 
-	if( isFlagClear(NEC2_SAVE) )
+	if( isFlagSet(IMAGE_SAVE) )
 	{
 	  /* cat a file extension if not already there */
 	  str = strstr( filename, ".png" );
@@ -832,27 +817,27 @@ on_fileselection_response(
 		  saveas_pixmap_height, filename );
 	}
 	else
-	{
-	  /* cat a file extension if not already there */
-	  str = strstr( filename, ".nec" );
-	  if( (str == NULL) || (str[4] != '\0') )
-		strcat( filename, ".nec" );
-	  /* Use new file name as input file */
-	  strcpy( infile, filename );
-	  Save_Nec2_Input_File( nec2_edit_window, filename );
-	  if( Nec2_Apply_Checkbutton() )
+	  if( isFlagSet(NEC2_SAVE) )
 	  {
-		/* Re-open NEC2 input file */
-		Open_Input_File(NULL);
-		Nec2_Input_File_Treeview( NEC2_EDITOR_SAVE );
+		/* cat a file extension if not already there */
+		str = strstr( filename, ".nec" );
+		if( (str == NULL) || (str[4] != '\0') )
+		  strcat( filename, ".nec" );
+		/* Use new file name as input file */
+		strcpy( infile, filename );
+		Save_Nec2_Input_File( nec2_edit_window, filename );
+		if( Nec2_Apply_Checkbutton() )
+		{
+		  /* Re-open NEC2 input file */
+		  Open_Input_File(NULL);
+		  Nec2_Input_File_Treeview( NEC2_EDITOR_SAVE );
+		}
 	  }
-	}
 
 	gtk_widget_destroy( file_selection );
-  } /* if( response_id == GTK_RESPONSE_OK ) */
-  else
 	if( kill_window == nec2_edit_window )
 	  gtk_widget_destroy( nec2_edit_window );
+  } /* if( response_id == GTK_RESPONSE_OK ) */
 }
 
 
@@ -887,7 +872,7 @@ on_freqplots_save_activate             (GtkMenuItem     *menuitem,
 
   /* Make file name from input file name,
    * to save frequency plots drawing */
-  sprintf( saveas, "%s-%s_%03d.%s", infile, "plots", ++cnt, "png" );
+  snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "plots", ++cnt, "png" );
 
   Save_Pixmap(
 	  freqplots_pixmap, freqplots_pixmap_width,
@@ -903,6 +888,7 @@ on_freqplots_save_as_activate          (GtkMenuItem     *menuitem,
   saveas_pixmap_width  = freqplots_pixmap_width;
   saveas_pixmap_height = freqplots_pixmap_height;
   ClearFlag( NEC2_SAVE );
+  SetFlag( IMAGE_SAVE );
 
   /* Open file selector to specify a file
    * name for saving the freq plots image */
@@ -911,18 +897,6 @@ on_freqplots_save_as_activate          (GtkMenuItem     *menuitem,
 }
 
 
-  void
-on_freqplots_about_activate            (GtkMenuItem     *menuitem,
-	gpointer         user_data)
-{
-  if( aboutdialog == NULL )
-  {
-	aboutdialog = create_aboutdialog();
-	gtk_widget_show( aboutdialog );
-  }
-}
-
-
   void
 on_freqplots_gmax_togglebutton_toggled (GtkToggleButton *togglebutton,
 										gpointer         user_data)
@@ -1061,10 +1035,10 @@ on_rdpattern_save_activate             (GtkMenuItem     *menuitem,
   /* Make the rad pattern save
    * file name from input name */
   if( isFlagSet(DRAW_GAIN) )
-	sprintf( saveas, "%s-%s_%03d.%s", infile, "gain", ++cgn, "png" );
+	snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "gain", ++cgn, "png" );
   else
 	if( isFlagSet(DRAW_EHFIELD) )
-	  sprintf( saveas, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
+	  snprintf( saveas, 96, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
 	else
 	  return;
 
@@ -1082,6 +1056,7 @@ on_rdpattern_save_as_activate          (GtkMenuItem     *menuitem,
   saveas_pixmap_width  = rdpattern_pixmap_width;
   saveas_pixmap_height = rdpattern_pixmap_height;
   ClearFlag( NEC2_SAVE );
+  SetFlag( IMAGE_SAVE );
 
   /* Open file selector to specify a file
    * name for saving the rad pattern image */
@@ -1182,18 +1157,6 @@ on_rdpattern_overlay_struct_activate   (GtkMenuItem     *menuitem,
 }
 
 
-  void
-on_rdpattern_about_activate            (GtkMenuItem     *menuitem,
-	gpointer         user_data)
-{
-  if( aboutdialog == NULL )
-  {
-	aboutdialog = create_aboutdialog();
-	gtk_widget_show( aboutdialog );
-  }
-}
-
-
   void
 on_rdpattern_x_axis_clicked            (GtkButton       *button,
 										gpointer         user_data)
@@ -1830,6 +1793,7 @@ on_nec2_editor_delete_event            (GtkWidget       *widget,
 		  GTK_FILE_SELECTION(file_selection), "untitled" );
 	  gtk_widget_show( file_selection );
 	  SetFlag( NEC2_SAVE );
+	  ClearFlag( IMAGE_SAVE );
 	  ClearFlag( NEC2_EDIT_SAVE );
 	  kill_window = nec2_edit_window;
 	  return TRUE;
@@ -1866,6 +1830,7 @@ on_nec2_save_clicked(
 		GTK_FILE_SELECTION(file_selection), "untitled" );
 	gtk_widget_show( file_selection );
 	SetFlag( NEC2_SAVE );
+	ClearFlag( IMAGE_SAVE );
 	return;
   }
 
@@ -1901,6 +1866,7 @@ on_nec2_save_as_clicked                (GtkButton       *button,
 	  GTK_FILE_SELECTION(file_selection), "untitled" );
   gtk_widget_show( file_selection );
   SetFlag( NEC2_SAVE );
+  ClearFlag( IMAGE_SAVE );
 }
 
 
@@ -2832,8 +2798,7 @@ on_scale_editor_destroy                (GtkObject       *object,
 
 
 void
-on_scale_factor_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
+on_scale_spinbutton_value_changed      (GtkSpinButton   *spinbutton,
                                         gpointer         user_data)
 {
   gtk_spin_button_update( spinbutton );
@@ -2841,6 +2806,7 @@ on_scale_factor_spinbutton_value_changed
 }
 
 
+
 void
 on_scale_new_button_clicked            (GtkButton       *button,
                                         gpointer         user_data)
@@ -3768,12 +3734,50 @@ on_loop_reset_clicked                  (GtkButton       *button,
   }
 }
 
-
+GtkWidget *aboutdialog = NULL;
 void
-on_aboutdialog_destroy                 (GtkObject       *object,
+on_about_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
+  if( aboutdialog == NULL )
+  {
+	aboutdialog = create_aboutdialog();
+	gtk_widget_show( aboutdialog );
+	gtk_about_dialog_set_version( GTK_ABOUT_DIALOG(aboutdialog), VERSION );
+  }
+}
+
+
+void
+on_aboutdialog_close                   (GtkDialog       *dialog,
+                                        gpointer         user_data)
+{
+  gtk_widget_destroy( aboutdialog );
   aboutdialog = NULL;
+}
+
+
+void
+on_aboutdialog_response                (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data)
+{
+  gtk_widget_destroy( aboutdialog );
+  aboutdialog = NULL;
+}
+
+
+void
+on_net_gain_activate                   (GtkMenuItem     *menuitem,
+	gpointer         user_data)
+{
+  if( gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)) )
+	SetFlag( PLOT_NETGAIN );
+  else
+	ClearFlag( PLOT_NETGAIN );
 
+  /* Trigger a redraw of frequency plots drawingarea */
+  if( isFlagSet(PLOT_ENABLED) && isFlagSet(FREQ_LOOP_DONE) )
+	Plot_Frequency_Data();
 }
 
