@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -2151,6 +2151,7 @@ Nearfield_Command( int action )
 			  nearfield_command, "nearfield_nh_checkbutton") );
 		gtk_toggle_button_set_active( toggle, FALSE );
 	  }
+
 	  if( strcmp(name, "NH") == 0 )
 	  {
 		nrhf = TRUE; nref = FALSE;
@@ -2162,6 +2163,7 @@ Nearfield_Command( int action )
 			  nearfield_command, "nearfield_ne_checkbutton") );
 		gtk_toggle_button_set_active( toggle, FALSE );
 	  }
+
 	  label = TRUE;
 	  break;
 
@@ -2435,7 +2437,7 @@ Intrange_Command( int action )
 
   /* Interaction Approx range */
   static gdouble kh;
-  static gchar skh[14];
+  static gchar skh[13];
 
   /* Card (row) name */
   gchar name[3];
@@ -2729,7 +2731,7 @@ Set_Command_Data(
 	GtkTreeIter *iter,
 	int *iv, double *fv )
 {
-  gchar sf[14];
+  gchar str[13];
   gint idx;
 
   /* Format and set editor data to treeview (I1-I4 & F1-F6) */
@@ -2737,18 +2739,18 @@ Set_Command_Data(
   {
 	for( idx = CMND_COL_I1; idx <= CMND_COL_I4; idx++ )
 	{
-	  snprintf( sf, 6, "%5d", iv[idx-CMND_COL_I1] );
-	  gtk_list_store_set( store, iter, idx, sf, -1 );
+	  snprintf( str, 6, "%5d", iv[idx-CMND_COL_I1] );
+	  gtk_list_store_set( store, iter, idx, str, -1 );
 	}
 
 	for( idx = CMND_COL_F1; idx <= CMND_COL_F6; idx++ )
 	{
-	  snprintf( sf, 13, "%12.5E", fv[idx-CMND_COL_F1] );
-	  gtk_list_store_set( store, iter, idx, sf, -1 );
+	  snprintf( str, 13, "%12.5E", fv[idx-CMND_COL_F1] );
+	  gtk_list_store_set( store, iter, idx, str, -1 );
 	}
   }
   else
-	stop( "Error writing row data:\n"
+	stop( "Error writing row data\n"
 		"Please re-select row", 0 );
 
   SetFlag( NEC2_EDIT_SAVE );
