@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -924,6 +924,7 @@ Arc_Editor( int action )
 	spin = GTK_SPIN_BUTTON( lookup_widget(arc_editor, ispin[idx]) );
 	iv[idx] = gtk_spin_button_get_value_as_int( spin );
   }
+
   /* Read float data from the arc editor */
   for( idx = ARC_RAD; idx <= ARC_RES; idx++ )
   {
@@ -1021,7 +1022,7 @@ Arc_Editor( int action )
 	gtk_spin_button_set_value( spin, iv[idx] );
   }
 
-  /* Write float data to the arc editor (F1 to F4 & pcl/angle) */
+  /* Write float data to the arc editor (F1 to F4 & pcl/resistance) */
   fv[ARC_DIA] *= 2.0;
   for( idx = ARC_RAD; idx <= ARC_RES; idx++ )
   {
@@ -1076,21 +1077,6 @@ Helix_Editor( int action )
   /* Card (row) name */
   gchar name[3];
 
-  /* GA card float data */
-  enum
-  {
-	HELIX_TSPACE = 0,
-	HELIX_LEN,
-	HELIX_RXZO,
-	HELIX_RYZO,
-	HELIX_RXZHL,
-	HELIX_RYZHL,
-	HELIX_DIA,
-	HELIX_PCL,
-	HELIX_NTURN,
-	HELIX_RES
-  };
-
   /* Spin button names, int & float data */
   gchar *ispin[2] =
   {
@@ -1489,13 +1475,23 @@ Scale_Editor( int action )
   /* For reading/writing to GS row */
   static GtkTreeIter iter_gs;
 
+  /* Integer type data */
+  static gint iv[2];
+
+  /* Spin button names, int data */
+  gchar *ispin[2] =
+  {
+	"scale_from_spinbutton",
+	"scale_to_spinbutton"
+  };
+
   int idx;
 
   /* Scale factor */
   static gdouble scale = 1.0;
 
   /* Card (row) name, strings for convertions */
-  gchar name[3], sf[14], *str;
+  gchar name[3], sf[13], *str;
 
   static gboolean
 	save = FALSE, /* Enable saving of editor data */
@@ -1512,6 +1508,9 @@ Scale_Editor( int action )
 	for( idx = GEOM_COL_I1; idx <= GEOM_COL_F7; idx++ )
 	  gtk_list_store_set( geom_store, &iter_gs, idx, "0", -1 );
 
+	/* Enter tag from-to data */
+	Set_Geometry_Int_Data( geom_store, &iter_gs, iv );
+
 	/* Enter scale factor */
 	snprintf( sf, 13, "%12.5E", scale );
 	gtk_list_store_set(
@@ -1543,6 +1542,9 @@ Scale_Editor( int action )
 	  Get_Selected_Row(
 		  geom_treeview, geom_store, &iter_gs, name );
 
+	  /* Get tag from-to data from tree view */
+	  Get_Geometry_Int_Data( geom_store, &iter_gs, iv );
+
 	  /* Get scale data from tree view */
 	  if( gtk_list_store_iter_is_valid(geom_store, &iter_gs) )
 	  {
@@ -1555,6 +1557,14 @@ Scale_Editor( int action )
 		stop( "Error reading row data\n"
 			"Invalid list iterator", 0 );
 
+	  /* Enter tag from-to data to scale editor */
+	  for( idx = SPIN_COL_I1; idx <= SPIN_COL_I2; idx++ )
+	  {
+		spin = GTK_SPIN_BUTTON(
+			lookup_widget(scale_editor, ispin[idx]) );
+		gtk_spin_button_set_value( spin, iv[idx] );
+	  }
+
 	  /* Set scale factor to scale editor */
 	  spin = GTK_SPIN_BUTTON(
 		  lookup_widget(scale_editor, "scale_factor_spinbutton") );
@@ -1568,6 +1578,14 @@ Scale_Editor( int action )
 	  return;
 
 	case EDITOR_DATA: /* Some data changed in editor window */
+	  /* Read int data from the scale editor */
+	  for( idx = SPIN_COL_I1; idx <= SPIN_COL_I2; idx++ )
+	  {
+		spin = GTK_SPIN_BUTTON(
+			lookup_widget(scale_editor, ispin[idx]) );
+		iv[idx] = gtk_spin_button_get_value_as_int( spin );
+	  }
+
 	  /* Read scale from the scale editor */
 	  spin = GTK_SPIN_BUTTON(
 		  lookup_widget(scale_editor, "scale_factor_spinbutton") );
@@ -2033,7 +2051,7 @@ Set_Geometry_Data(
 	GtkTreeIter *iter,
 	int *iv, double *fv )
 {
-  gchar sf[14];
+  gchar str[13];
   gint idx;
 
   /* Format and set editor data to treeview (I1, I2 & F1-F7) */
@@ -2041,18 +2059,18 @@ Set_Geometry_Data(
   {
 	for( idx = GEOM_COL_I1; idx <= GEOM_COL_I2; idx++ )
 	{
-	  snprintf( sf, 6, "%5d", iv[idx-GEOM_COL_I1] );
-	  gtk_list_store_set( store, iter, idx, sf, -1 );
+	  snprintf( str, 6, "%5d", iv[idx-GEOM_COL_I1] );
+	  gtk_list_store_set( store, iter, idx, str, -1 );
 	}
 
 	for( idx = GEOM_COL_F1; idx <= GEOM_COL_F7; idx++ )
 	{
-	  snprintf( sf, 13, "%12.5E", fv[idx-GEOM_COL_F1] );
-	  gtk_list_store_set( store, iter, idx, sf, -1 );
+	  snprintf( str, 13, "%12.5E", fv[idx-GEOM_COL_F1] );
+	  gtk_list_store_set( store, iter, idx, str, -1 );
 	}
   }
   else
-	stop( "Error writing row data:\n"
+	stop( "Error writing row data\n"
 		"Please re-select row", 0 );
 
   SetFlag( NEC2_EDIT_SAVE );
@@ -2069,7 +2087,7 @@ Set_Geometry_Data(
   void
 Set_Geometry_Int_Data( GtkListStore *store, GtkTreeIter *iter, int *iv )
 {
-  gchar sf[6];
+  gchar str[6];
   gint idx;
 
   /* Format and set editor data to treeview (I1, I2) */
@@ -2077,8 +2095,8 @@ Set_Geometry_Int_Data( GtkListStore *store, GtkTreeIter *iter, int *iv )
   {
 	for( idx = GEOM_COL_I1; idx <= GEOM_COL_I2; idx++ )
 	{
-	  snprintf( sf, 6, "%5d", iv[idx-GEOM_COL_I1] );
-	  gtk_list_store_set( store, iter, idx, sf, -1 );
+	  snprintf( str, 6, "%5d", iv[idx-GEOM_COL_I1] );
+	  gtk_list_store_set( store, iter, idx, str, -1 );
 	}
 
 	/* Clear unused float columns */
@@ -2086,7 +2104,7 @@ Set_Geometry_Int_Data( GtkListStore *store, GtkTreeIter *iter, int *iv )
 	  gtk_list_store_set( store, iter, idx, "0.0", -1 );
   }
   else
-	stop( "Error writing row data:\n"
+	stop( "Error writing row data\n"
 		"Please re-select row", 0 );
 
   SetFlag( NEC2_EDIT_SAVE );
@@ -2261,7 +2279,8 @@ Get_Selected_Row(
   /* Get row name */
   gtk_tree_model_get(
 	  GTK_TREE_MODEL(store), iter, GEOM_COL_NAME, &str, -1);
-  strncpy( name, str, 3 );
+  strncpy( name, str, 2 );
+  name[2] = '\0';
   g_free( str );
 
   return( TRUE );
@@ -2281,7 +2300,7 @@ Set_Wire_Conductivity( int tag, double s, GtkListStore *store )
 {
   int idx, nchld;
   GtkTreeIter iter_ld;
-  gchar *str, sv[14];
+  gchar *str, sv[13];
 
   /* Find num of rows and first iter, abort if tree empty */
   nchld = gtk_tree_model_iter_n_children(
