@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -119,7 +119,7 @@ arc( int itg, int ns, long double rada,
   else
   {
 	fprintf( stderr,
-		"\nxnec2c: arc() - arc angle exceeds 360 degrees");
+		"xnec2c: arc() - arc angle exceeds 360 degrees\n");
 	stop( "Arc angle exceeds 360 degrees", 1 );
   }
 
@@ -157,7 +157,7 @@ conect( int ignd )
 	if( data.np > data.n)
 	{
 	  fprintf( stderr,
-		  "\nxnec2c: error - np > n in conect()" );
+		  "xnec2c: error - np > n in conect()\n" );
 	  stop( "conect(): np > n", 1 );
 	}
 
@@ -194,9 +194,9 @@ conect( int ignd )
 		if( zi1 <= -slen)
 		{
 		  fprintf( stderr,
-			  "\nxnec2c: geometry data error -- segment"
-			  " %d extends below ground", iz );
-		  stop( "Geometry data error:\n"
+			  "xnec2c: geometry data error\n"
+			  "segment %d extends below ground\n", iz );
+		  stop( "Geometry data error\n"
 			  "Segment extends below ground", 1 );
 		}
 
@@ -245,9 +245,9 @@ conect( int ignd )
 		if( zi2 <= -slen)
 		{
 		  fprintf( stderr,
-			  "\nxnec2c: geometry data error -- segment"
-			  " %d extends below ground", iz );
-		  stop( "Geometry data error:\n"
+			  "xnec2c: geometry data error\n"
+			  "segment %d extends below ground\n", iz );
+		  stop( "Geometry data error\n"
 			  "Segment extends below ground", 1 );
 		}
 
@@ -256,9 +256,9 @@ conect( int ignd )
 		  if( data.icon1[i] == iz )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data error -- segment"
-				" %d lies in ground plane", iz );
-			stop( "Geometry data error:\n"
+				"xnec2c: geometry data error\n"
+				"segment %d lies in ground plane\n", iz );
+			stop( "Geometry data error\n"
 				"Segment lies in ground plane", 1 );
 		  }
 
@@ -357,7 +357,7 @@ conect( int ignd )
 	if( data.ipsym == 0 )
 	{
 	  fprintf( stderr,
-		  "\nxnec2c: error: ipsym = 0 in conect()" );
+		  "xnec2c: error: ipsym = 0 in conect()\n" );
 	  stop( "Error: ipsym = 0 in conect()", 1 );
 	}
 
@@ -399,8 +399,8 @@ conect( int ignd )
 		  if( ix == 0 )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: connect - segment connection"
-				" error for segment: %d", ix );
+				"xnec2c: connect - segment connection"
+				" error for segment: %d\n", ix );
 			stop( "Segment connection error", 1 );
 		  }
 
@@ -624,8 +624,8 @@ int isegno( int itagi, int mx)
   if( mx <= 0)
   {
 	fprintf( stderr,
-		"\nxnec2c: check data, parameter specifying segment"
-		"\nposition in a group of equal tags must not be zero" );
+		"xnec2c: check data, parameter specifying segment\n"
+		"position in a group of equal tags must not be zero\n" );
 	stop( "Parameter specifying segment position\n"
 		"in a group of equal tags is zero", 1 );
   }
@@ -656,7 +656,7 @@ int isegno( int itagi, int mx)
   } /* if( data.n > 0) */
 
   fprintf( stderr,
-	  "\nxnec2c: no segment has an itag of %d",  itagi );
+	  "xnec2c: no segment has an itag of %d\n",  itagi );
   stop( "Segment tag number error", 1 );
   return(1);
 }
@@ -969,8 +969,8 @@ patch(
 		if( s1x <= 0.9998l)
 		{
 		  fprintf( stderr,
-			  "\nxnec2c: error -- corners of quadrilateral"
-			  "\npatch do not lie in a plane" );
+			  "xnec2c: error -- corners of quadrilateral\n"
+			  "patch do not lie in a plane\n" );
 		  stop( "Corners of quadrilateral patch\n"
 			  "do not lie in a plane", 1);
 		}
@@ -1213,9 +1213,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 		  if( (fabsl(e1)+fabsl(e2) <= 1.0e-5l) || (e1*e2 < -1.0e-6l) )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data error:"
-				"\nsegment %d lies in plane of symmetry", i+1 );
-			stop( "Geometry data error:\n"
+				"xnec2c: geometry data error\n"
+				"segment %d lies in plane of symmetry\n", i+1 );
+			stop( "Geometry data error\n"
 				"Segment lies in plane of symmetry", 1 );
 		  }
 
@@ -1263,9 +1263,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 		  if( fabsl(data.pz[i]) <= 1.0e-10l)
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data error:"
-				"\npatch %d lies in plane of symmetry", i+1 );
-			stop( "Geometry data error:\n"
+				"xnec2c: geometry data error\n"
+				"patch %d lies in plane of symmetry\n", i+1 );
+			stop( "Geometry data error\n"
 				"Patch lies in plane of symmetry", 1 );
 		  }
 
@@ -1315,9 +1315,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 		  if( (fabsl(e1)+fabsl(e2) <= 1.0e-5l) || (e1*e2 < -1.0e-6l) )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data error:"
-				"\nsegment %d lies in plane of symmetry", i+1 );
-			stop( "Geometry data error:\n"
+				"xnec2c: geometry data error\n"
+				"segment %d lies in plane of symmetry\n", i+1 );
+			stop( "Geometry data error\n"
 				"Segment lies in plane of symmetry", 1 );
 		  }
 
@@ -1365,9 +1365,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 		  if( fabsl( data.py[i]) <= 1.0e-10l)
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data error:"
-				"\npatch %d lies in plane of symmetry", i+1 );
-			stop( "Geometry data error:\n"
+				"xnec2c: geometry data error\n"
+				"patch %d lies in plane of symmetry\n", i+1 );
+			stop( "Geometry data error\n"
 				"Patch lies in plane of symmetry", 1 );
 		  }
 
@@ -1420,9 +1420,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 		if( (fabsl(e1)+fabsl(e2) <= 1.0e-5l) || (e1*e2 < -1.0e-6l) )
 		{
 		  fprintf( stderr,
-			  "\nxnec2c: geometry data error:"
-			  "\nsegment %d lies in plane of symmetry", i+1 );
-		  stop( "Geometry data error:\n"
+			  "xnec2c: geometry data error\n"
+			  "segment %d lies in plane of symmetry\n", i+1 );
+		  stop( "Geometry data error\n"
 			  "Segment lies in plane of symmetry", 1 );
 		}
 
@@ -1469,9 +1469,9 @@ reflc( int ix, int iy, int iz, int itx, int nop )
 	  if( fabsl( data.px[i]) <= 1.0e-10l)
 	  {
 		fprintf( stderr,
-			"\nxnec2c: geometry data error:"
-			"\npatch %d lies in plane of symmetry", i+1 );
-		stop( "Geometry data error:\n"
+			"xnec2c: geometry data error\n"
+			"patch %d lies in plane of symmetry\n", i+1 );
+		stop( "Geometry data error\n"
 			"Patch lies in plane of symmetry", 1 );
 	  }
 
