@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ Read_Comments( void )
 
   /* read a line from input file */
   if( load_line(line_buf, input_fp) == EOF )
-	stop( "Error reading input file:\n"
+	stop( "Error reading input file\n"
 		  "Unexpected EOF (End of File)", 1 );
 
   /* separate card's id mnemonic */
@@ -121,7 +121,7 @@ Read_Comments( void )
 	{
 	  /* read a line from input file */
 	  if( load_line(line_buf, input_fp) == EOF )
-		stop( "Error reading input file:\n"
+		stop( "Error reading input file\n"
 			  "Unexpected EOF (End of File)", 1 );
 
 	  /* separate card's id mnemonic */
@@ -313,7 +313,7 @@ Read_Commands( void )
 		continue;
 
 	  case 1: /* "cp" card ignored, maximum coupling between antennas */
-		stop( "CP card is ignored.\n"
+		stop( "CP card is ignored\n"
 			"Coupling calculation not implemented", 0 );
 		continue; /* continue card input loop */
 
@@ -503,8 +503,8 @@ Read_Commands( void )
 		  if( gnd.iperf == 2)
 		  {
 			fprintf( stderr,
-				"\nxnec2c: radial wire g.s. approximation may"
-				"\nnot be used with Sommerfeld ground option" );
+				"xnec2c: radial wire g.s. approximation may\n"
+				"not be used with Sommerfeld ground option\n" );
 			stop( "Radial wire g.s. approximation may not\n"
 				"be used with Sommerfeld ground option", 1 );
 		  }
@@ -559,10 +559,10 @@ Read_Commands( void )
 		  if( itmp4 < itmp3 )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: data fault on loading card no: %d:"
-				"\nitag step1: %d is greater than itag step2: %d",
+				"xnec2c: data fault on loading card no %d\n"
+				"itag step1 %d is greater than itag step2 %d\n",
 				zload.nload, itmp3, itmp4 );
-			stop( "Data fault on loading card:\n"
+			stop( "Data fault on loading card\n"
 				"itag step1 is greater than itag step2", 1 );
 		  }
 
@@ -813,7 +813,7 @@ Read_Commands( void )
 
 	  default:
 		fprintf( stderr,
-			"\nxnec2c: faulty data card label after geometry section" );
+			"xnec2c: faulty data card label after geometry section\n" );
 		stop( "Faulty data card label\n"
 			"after geometry section", 1 );
 	} /* switch( ain_num ) */
@@ -852,10 +852,10 @@ readmn( char *gm, int *i1, int *i2, int *i3, int *i4,
   {
 	gm[0] = '\0';
 	fprintf( stderr,
-		"\nxnec2c: command data card error:"
-		"\ncard's mnemonic code too short or missing." );
-	stop( "Command data card error:\n"
-		"Mnemonic code too short or missing.", err );
+		"xnec2c: command data card error\n"
+		"card's mnemonic code too short or missing\n" );
+	stop( "Command data card error\n"
+		"Mnemonic code too short or missing", err );
   }
 
   /* extract card's mnemonic code */
@@ -913,16 +913,16 @@ readmn( char *gm, int *i1, int *i2, int *i3, int *i4,
 	{
 	  /* test for non-numerical characters */
 	  if( ((line_buf[line_idx] <  '0')  ||
-			(line_buf[line_idx] >  '9')) &&
-		  (line_buf[line_idx] != '+')  &&
-		  (line_buf[line_idx] != '-') )
+		   (line_buf[line_idx] >  '9')) &&
+		   (line_buf[line_idx] != '+')  &&
+		   (line_buf[line_idx] != '-') )
 	  {
 		gm[0] = '\0';
 		fprintf( stderr,
-			"\nxnec2c: command data card \"%s\" error:"
-			"\nnon-numerical char: '%c' in integer field at char: %d\n",
+			"xnec2c: command data card \"%s\" error\n"
+			"non-numerical char '%c' in integer field at char %d\n",
 			gm, line_buf[line_idx], (line_idx+1) );
-		stop( "Command data card error:\n"
+		stop( "Command data card error\n"
 			"Non-numerical character in integer field", err );
 	  }
 
@@ -952,9 +952,9 @@ readmn( char *gm, int *i1, int *i2, int *i3, int *i4,
 	/* Find first numerical character */
 	while( ((line_buf[++line_idx] <  '0')  ||
 		  (line_buf[  line_idx] >  '9')) &&
-		(line_buf[  line_idx] != '+')  &&
-		(line_buf[  line_idx] != '-')  &&
-		(line_buf[  line_idx] != '.') )
+		  (line_buf[  line_idx] != '+')  &&
+		  (line_buf[  line_idx] != '-')  &&
+		  (line_buf[  line_idx] != '.') )
 	  if( (line_buf[line_idx] == '\0') )
 	  {
 		*i1= iarr[0];
@@ -973,7 +973,7 @@ readmn( char *gm, int *i1, int *i2, int *i3, int *i4,
 	/* read a long double from line */
 	rarr[i] = atof( &line_buf[line_idx] );
 
-	/* traverse numerical field to next ' ' or ',' */
+	/* traverse numerical field to next ' ' or ',' or '\0'*/
 	line_idx--;
 	while(
 		(line_buf[++line_idx] != ' ') &&
@@ -983,19 +983,19 @@ readmn( char *gm, int *i1, int *i2, int *i3, int *i4,
 	{
 	  /* test for non-numerical characters */
 	  if( ((line_buf[line_idx] <  '0')  ||
-			(line_buf[line_idx] >  '9')) &&
-		  (line_buf[line_idx] != '.')  &&
-		  (line_buf[line_idx] != '+')  &&
-		  (line_buf[line_idx] != '-')  &&
-		  (line_buf[line_idx] != 'E')  &&
-		  (line_buf[line_idx] != 'e') )
+		   (line_buf[line_idx] >  '9')) &&
+		   (line_buf[line_idx] != '.')  &&
+		   (line_buf[line_idx] != '+')  &&
+		   (line_buf[line_idx] != '-')  &&
+		   (line_buf[line_idx] != 'E')  &&
+		   (line_buf[line_idx] != 'e') )
 	  {
 		gm[0] = '\0';
 		fprintf( stderr,
-			"\nxnec2c: command data card \"%s\" error:"
-			"\nnon-numerical char: '%c' in float field at char: %d\n",
+			"xnec2c: command data card \"%s\" error\n"
+			"non-numerical char '%c' in float field at char %d\n",
 			gm, line_buf[line_idx], (line_idx+1) );
-		stop( "Command data card error:\n"
+		stop( "Command data card error\n"
 			"Non-numerical character in float field", err );
 	  }
 
@@ -1058,9 +1058,9 @@ readgm( char *gm, int *i1, int *i2, long double *x1,
   {
 	gm[0] = '\0';
 	fprintf( stderr,
-		"\nxnec2c: geometry data card error: "
-		"card's mnemonic code too short or missing." );
-	stop( "Geometry data card error:\n"
+		"xnec2c: geometry data card error\n"
+		"card's mnemonic code too short or missing\n" );
+	stop( "Geometry data card error\n"
 		"Card's mnemonic code too short or missing", err );
   }
 
@@ -1082,10 +1082,10 @@ readgm( char *gm, int *i1, int *i2, long double *x1,
   {
 	/* Find first numerical character */
 	while(
-		((line_buf[++line_idx] <  '0') ||
+		((line_buf[++line_idx] <  '0')  ||
 		 (line_buf[  line_idx] >  '9')) &&
-		(line_buf[  line_idx] != '+')  &&
-		(line_buf[  line_idx] != '-') )
+		 (line_buf[  line_idx] != '+')  &&
+		 (line_buf[  line_idx] != '-') )
 	  if( (line_buf[line_idx] == '\0') )
 	  {
 		*i1 = iarr[0];
@@ -1113,17 +1113,17 @@ readgm( char *gm, int *i1, int *i2, long double *x1,
 	{
 	  /* test for non-numerical characters */
 	  if(
-		  ((line_buf[line_idx] <  '0') ||
+		  ((line_buf[line_idx] <  '0')  ||
 		   (line_buf[line_idx] >  '9')) &&
-		  (line_buf[line_idx] != '+')  &&
-		  (line_buf[line_idx] != '-') )
+		   (line_buf[line_idx] != '+')  &&
+		   (line_buf[line_idx] != '-') )
 	  {
 		gm[0] = '\0';
 		fprintf( stderr,
-			"\nxnec2c: geometry data card \"%s\" error:"
-			"\nnon-numerical char: '%c' in integer field at char: %d\n",
+			"xnec2c: geometry data card \"%s\" error\n"
+			"non-numerical char '%c' in integer field at char %d\n",
 			gm, line_buf[line_idx], (line_idx+1)  );
-		stop( "Geometry data card error:\n"
+		stop( "Geometry data card error\n"
 			"Non-numerical character in integer field", err );
 	  }
 
@@ -1176,27 +1176,27 @@ readgm( char *gm, int *i1, int *i2, long double *x1,
 	/* traverse numerical field to next ' ' or ',' or '\0' */
 	line_idx--;
 	while(
-		(line_buf[++line_idx] != ' ')  &&
+		(line_buf[++line_idx] != ' ') &&
 		(line_buf[  line_idx] != '	') &&
-		(line_buf[  line_idx] != ',')  &&
+		(line_buf[  line_idx] != ',') &&
 		(line_buf[  line_idx] != '\0') )
 	{
 	  /* test for non-numerical characters */
 	  if(
-		  ((line_buf[line_idx] <  '0') ||
+		  ((line_buf[line_idx] <  '0')  ||
 		   (line_buf[line_idx] >  '9')) &&
-		  (line_buf[line_idx] != '.')  &&
-		  (line_buf[line_idx] != '+')  &&
-		  (line_buf[line_idx] != '-')  &&
-		  (line_buf[line_idx] != 'E')  &&
-		  (line_buf[line_idx] != 'e') )
+		   (line_buf[line_idx] != '.')  &&
+		   (line_buf[line_idx] != '+')  &&
+		   (line_buf[line_idx] != '-')  &&
+		   (line_buf[line_idx] != 'E')  &&
+		   (line_buf[line_idx] != 'e') )
 	  {
 		gm[0] = '\0';
 		fprintf( stderr,
-			"\nxnec2c: geometry data card \"%s\" error:"
-			"\nNon-numerical char: '%c' in float field at char: %d.\n",
+			"xnec2c: geometry data card \"%s\" error\n"
+			"Non-numerical char '%c' in float field at char %d\n",
 			gm, line_buf[line_idx], (line_idx+1) );
-		stop( "Geometry data card error:\n"
+		stop( "Geometry data card error\n"
 			"Non-numerical character in float field", err );
 	  }
 
@@ -1298,15 +1298,15 @@ datagn( void )
 		  if( strcmp(gm, "GC" ) != 0 )
 		  {
 			fprintf( stderr,
-				"\nxnec2c: geometry data card error: "
+				"xnec2c: geometry data card error "
 				"no GC card for tapered wire\n" );
-			stop( "Geometry data error:\n"
+			stop( "Geometry data error\n"
 				"No GC card for tapered wire", 1 );
 		  }
 
 		  if( (ys1 == 0) || (zs1 == 0) )
 		  {
-			fprintf( stderr, "\nxnec2c: geometry GC data card error" );
+			fprintf( stderr, "xnec2c: geometry GC data card error\n" );
 			stop( "Geometry GC data card error", 1 );
 		  }
 
@@ -1322,7 +1322,7 @@ datagn( void )
 	  case 1: /* "gx" card */
 		if( (ns < 0) || (itg < 0) )
 		{
-		  fprintf( stderr, "\nxnec2c: geometry GX data card error" );
+		  fprintf( stderr, "xnec2c: geometry GX data card error\n" );
 		  stop( "Geometry GX data card error", 1 );
 		}
 
@@ -1344,7 +1344,7 @@ datagn( void )
 	  case 2: /* "gr" card */
 		if( (ns < 0) || (itg < 0) )
 		{
-		  fprintf( stderr, "\nxnec2c: geometry GR data card error" );
+		  fprintf( stderr, "xnec2c: geometry GR data card error\n" );
 		  stop( "Geometry GR data card error", 1 );
 		}
 
@@ -1355,8 +1355,21 @@ datagn( void )
 
 	  case 3: /* "gs" card, scale structure dimensions by factor xw1 */
 
-		if( data.n > 0)
-		{
+		if( (itg > 0) && (ns > 0) && (ns >= itg) )
+		  for( i = 0; i < data.n; i++ )
+		  {
+			if( (data.itag[i] >= itg) && (data.itag[i] <= ns) )
+			{
+			  data.x1[i]= data.x1[i]* xw1;
+			  data.y1[i]= data.y1[i]* xw1;
+			  data.z1[i]= data.z1[i]* xw1;
+			  data.x2[i]= data.x2[i]* xw1;
+			  data.y2[i]= data.y2[i]* xw1;
+			  data.z2[i]= data.z2[i]* xw1;
+			  data.bi[i]= data.bi[i]* xw1;
+			}
+		  }
+		else
 		  for( i = 0; i < data.n; i++ )
 		  {
 			data.x1[i]= data.x1[i]* xw1;
@@ -1367,19 +1380,15 @@ datagn( void )
 			data.z2[i]= data.z2[i]* xw1;
 			data.bi[i]= data.bi[i]* xw1;
 		  }
-		} /* if( data.n >= n2) */
 
-		if( data.m > 0)
+		yw1= xw1* xw1;
+		for( i = 0; i < data.m; i++ )
 		{
-		  yw1= xw1* xw1;
-		  for( i = 0; i < data.m; i++ )
-		  {
-			data.px[i]= data.px[i]* xw1;
-			data.py[i]= data.py[i]* xw1;
-			data.pz[i]= data.pz[i]* xw1;
-			data.pbi[i]= data.pbi[i]* yw1;
-		  }
-		} /* if( data.m >= m2) */
+		  data.px[i] = data.px[i]* xw1;
+		  data.py[i] = data.py[i]* xw1;
+		  data.pz[i] = data.pz[i]* xw1;
+		  data.pbi[i]= data.pbi[i]* yw1;
+		}
 		continue;
 
 	  case 4: /* "ge" card, terminate structure geometry input. */
@@ -1429,7 +1438,7 @@ datagn( void )
 
 			if( (data.si[i] <= 1.0e-20l) || (data.bi[i] <= 0.0l) )
 			{
-			  fprintf( stderr, "\nxnec2c: segment data error" );
+			  fprintf( stderr, "xnec2c: segment data error\n" );
 			  stop( "Segment data error", 1 );
 			}
 
@@ -1464,7 +1473,7 @@ datagn( void )
 		  int tgf = (int)(rad + 0.5l);
 		  if( (tgf < 0) || (ns < 0) || (rad < 0.0l) )
 		  {
-			fprintf( stderr, "\nxnec2c: move GM data card error" );
+			fprintf( stderr, "xnec2c: move GM data card error\n" );
 			stop( "Move GM data card error", 1 );
 		  }
 		  xw1= xw1* TA;
@@ -1480,7 +1489,7 @@ datagn( void )
 
 		if( itg != 0)
 		{
-		  fprintf( stderr, "\nxnec2c: patch data card error" );
+		  fprintf( stderr, "xnec2c: patch data card error\n" );
 		  stop( "Patch data card error", 1 );
 		}
 
@@ -1501,7 +1510,7 @@ datagn( void )
 
 		  if( strcmp(gm, "SC") != 0 )
 		  {
-			fprintf( stderr, "\nxnec2c: patch data error" );
+			fprintf( stderr, "xnec2c: patch data error\n" );
 			stop( "Patch data error", 1 );
 		  }
 
@@ -1520,7 +1529,7 @@ datagn( void )
 		i1= data.m+1;
 		if( (itg < 1) || (ns < 1) )
 		{
-		  fprintf( stderr, "\nxnec2c: patch card data error" );
+		  fprintf( stderr, "xnec2c: patch card data error\n" );
 		  stop( "Patch data card error", 1 );
 		}
 
@@ -1536,7 +1545,7 @@ datagn( void )
 
 		if( strcmp(gm, "SC" ) != 0 )
 		{
-		  fprintf( stderr, "\nxnec2c: patch card data error" );
+		  fprintf( stderr, "xnec2c: patch card data error\n" );
 		  stop( "Patch data card error", 1 );
 		}
 
@@ -1556,7 +1565,7 @@ datagn( void )
 	  case 9: /* "sc" card */
 		if( isct == 0)
 		{
-		  fprintf( stderr, "\nxnec2c: patch data card error" );
+		  fprintf( stderr, "xnec2c: patch data card error\n" );
 		  stop( "Patch data card error", 1 );
 		}
 
@@ -1565,7 +1574,7 @@ datagn( void )
 
 		if( (itg != 0) || ((ns != 2) && (ns != 4)) )
 		{
-		  fprintf( stderr, "\nxnec2c: patch data card error" );
+		  fprintf( stderr, "xnec2c: patch data card error\n" );
 		  stop( "Patch data card error", 1 );
 		}
 
@@ -1618,9 +1627,9 @@ datagn( void )
 			"is not supported", 1 );
 
 	  default: /* error message */
-		fprintf( stderr, "\nxnec2c: geometry data card error" );
+		fprintf( stderr, "xnec2c: geometry data card error\n" );
 		fprintf( stderr,
-			"\n%2s %3d %5d %10.5LF %10.5LF %10.5LF"
+			"%2s %3d %5d %10.5LF %10.5LF %10.5LF"
 			" %10.5LF %10.5LF %10.5LF %10.5LF\n",
 			gm, itg, ns, xw1, yw1, zw1, xw2, yw2, zw2, rad );
 
@@ -1647,9 +1656,9 @@ Tag_Seg_Error( int tag, int segs )
   if( tag <= 0 )
   {
 	fprintf( stderr,
-		"\nxnec2c: geometry data card error: "
-		"tag number is less than 1" );
-	stop( "Geometry data error:\n"
+		"xnec2c: geometry data card error\n"
+		"tag number is less than 1\n" );
+	stop( "Geometry data error\n"
 		"Tag number is less than 1", 1 );
 	retv = TRUE;
   }
@@ -1657,9 +1666,9 @@ Tag_Seg_Error( int tag, int segs )
   if( segs <= 0 )
   {
 	fprintf( stderr,
-		"\nxnec2c: geometry data card error: "
-		"number of segments is less than 1" );
-	stop( "Geometry data error:\n"
+		"xnec2c: geometry data card error\n"
+		"number of segments is less than 1\n" );
+	stop( "Geometry data error\n"
 		"Number of segments is less than 1", 1 );
 	retv = TRUE;
   }
