@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1230,7 +1230,7 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 	if( iflg == TRUE )
 	{
 	  fprintf( stderr,
-		  "\nxnec2c: pivot(%d)= %16.8LE", r, dmax );
+		  "xnec2c: pivot(%d)= %16.8LE\n", r, dmax );
 	  iflg=FALSE;
 	}
 
@@ -1291,8 +1291,8 @@ fblock( int nrow, int ncol, int imax, int ipsym )
   if( smat.nop*nrow != ncol)
   {
 	fprintf( stderr,
-		"\nxnec2c: symmetry error - nrow:%d ncol:%d",nrow, ncol );
-	stop( "fblock(): symmetry error:", 1 );
+		"xnec2c: symmetry error - nrow:%d ncol:%d\n",nrow, ncol );
+	stop( "fblock(): symmetry error", 1 );
   }
 
   /* set up smat.ssx matrix for rotational symmetry. */
@@ -1346,7 +1346,7 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 /* subroutine to solve the matrix equation lu*x=b where l is a unit */
 /* lower triangular matrix and u is an upper triangular matrix both */
 /* of which are stored in a.  the rhs vector b is input and the */
-/* solution is returned through vector b.   (matrix transposed. */
+/* solution is returned through vector b.   (matrix transposed) */
 void solve( int n, complex long double *a, int *ip,
 	complex long double *b, int ndim )
 {
