@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ Nec2_Input_File_Treeview( int action )
   /* float data from cards */
   long double fv[7];
 
-  /* For sprintf */
+  /* For snprintf */
   char si[4][7], sf[7][13];
 
   int idx;
@@ -164,7 +164,7 @@ Nec2_Input_File_Treeview( int action )
 
 	/* Append a default comment row */
 	strcpy( str, "--- NEC2 Input File created by " );
-	strcat( str, version );
+	strcat( str, PACKAGE"-"VERSION);
 	strcat( str, " ---" );
 	gtk_list_store_append( cmnt_store, &iter );
 	gtk_list_store_set(
@@ -305,7 +305,7 @@ Nec2_Input_File_Treeview( int action )
 	/*** Read comments ***/
 	/* Read a line from input file */
 	if( load_line(line_buf, input_fp) == EOF )
-	  stop( "Error reading input file:\n"
+	  stop( "Error reading input file\n"
 		  "Unexpected EOF (End of File)", 1 );
 
 	/* Separate card's id mnemonic */
@@ -340,7 +340,7 @@ Nec2_Input_File_Treeview( int action )
 
 	  /* Read a line from input file */
 	  if( load_line(line_buf, input_fp) == EOF )
-		stop( "Error reading input file:\n"
+		stop( "Error reading input file\n"
 			"Unexpected EOF (End of File)", 1 );
 
 	  /* Separate card's id mnemonic */
@@ -436,11 +436,9 @@ Nec2_Input_File_Treeview( int action )
 
 	  /* Format card data and print to string */
 	  for( idx = CMND_COL_I1; idx < CMND_COL_I4; idx++ )
-		snprintf( si[idx-CMND_COL_I1], 6,
-			"%5d", iv[idx-CMND_COL_I1] );
+		snprintf( si[idx-CMND_COL_I1], 6, "%5d", iv[idx-CMND_COL_I1] );
 	  /* For alignment of data printed to NEC2 file */
-	  snprintf( si[idx-CMND_COL_I1],   7,
-		  " %5d", iv[idx-CMND_COL_I1] );
+	  snprintf( si[idx-CMND_COL_I1], 7, " %5d", iv[idx-CMND_COL_I1] );
 	  for( idx = CMND_COL_F1; idx <= CMND_COL_F6; idx++ )
 		snprintf( sf[idx-CMND_COL_F1], 13,
 			"%12.5E", (double)fv[idx-CMND_COL_F1] );
