@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -693,7 +693,7 @@ void rdpat()
 	  {
 		if( rdpattern_window != NULL )
 		  gtk_widget_destroy( rdpattern_window );
-		stop( "Theta > 90 deg. with ground specified.\n"
+		stop( "Theta > 90 deg. with ground specified\n"
 			"Please check RP card data and correct", 1 );
 	  }
 
