@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -221,9 +221,9 @@ Ground_Parameters( void )
 		if( cabsl(( ggrid.epscf - epsc) / epsc) >= 1.0e-3l )
 		{
 		  fprintf( stderr,
-			  "\nxnec2c: error in ground parameters -"
-			  "\ncomplex dielectric constant from file: %12.5LE%+12.5LEj"
-			  "\n                            requested: %12.5LE%+12.5LEj",
+			  "xnec2c: error in ground parameters\n"
+			  "complex dielectric constant from file: %12.5LE%+12.5LEj\n"
+			  "                            requested: %12.5LE%+12.5LEj\n",
 			  creall(ggrid.epscf), cimagl(ggrid.epscf),
 			  creall(epsc), cimagl(epsc) );
 		  stop( "Error in ground parameters", 1 );
