@@ -1,6 +1,6 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
+ *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,9 +39,6 @@
 #include <sys/times.h>
 #include <gtk/gtk.h>
 
-/* Version string for the -v option */
-#define	version "xnec2c 1.0-beta"
-
 #ifndef	TRUE
 #define	TRUE	1
 #endif
@@ -152,42 +149,45 @@
 #define	PLOT_ZMAG_ZPHASE	0x0000000000001000ll
 #define	PLOT_GMAX			0x0000000000002000ll
 #define	PLOT_GVIEWER		0x0000000000004000ll
-#define	PLOT_GAIN_DIR		0x0000000000008000ll
-#define	PLOT_FREQ_LINE		0x0000000000010000ll
-#define	PLOT_SELECT			0x0000000000020000ll
-#define	PLOT_ENABLED		0x0000000000040000ll
-#define	PLOT_QUIT			0x0000000000080000ll
-#define	PLOT_FLAGS			0x00000000000FFC00ll
+#define	PLOT_NETGAIN		0x0000000000008000ll
+#define	PLOT_GAIN_DIR		0x0000000000010000ll
+#define	PLOT_FREQ_LINE		0x0000000000020000ll
+#define	PLOT_SELECT			0x0000000000040000ll
+#define	PLOT_ENABLED		0x0000000000080000ll
+#define	PLOT_QUIT			0x0000000000100000ll
+#define	PLOT_FLAGS			0x00000000001FFC00ll
 
 /* Radiation Pattern Control flags */
-#define	DRAW_GAIN			0x0000000000100000ll
-#define	DRAW_EFIELD			0x0000000000200000ll
-#define	DRAW_HFIELD			0x0000000000400000ll
-#define	DRAW_EHFIELD		0x0000000000800000ll
-#define	DRAW_POYNTING		0x0000000001000000ll
-#define	DRAW_ENABLED		0x0000000002000000ll
-#define	DRAW_QUIT			0x0000000004000000ll
-#define	DRAW_NEWRDPAT		0x0000000008000000ll
-#define	OVERLAY_STRUCT		0x0000000010000000ll
-#define	NEAREH_SNAPSHOT		0x0000000020000000ll
-#define	NEAREH_ANIMATE		0x0000000040000000ll
-#define	ENABLE_RDPAT		0x0000000080000000ll
-#define	ENABLE_NEAREH		0x0000000100000000ll
-#define	DRAW_FLAGS			0x000000007FF00000ll
+#define	DRAW_GAIN			0x0000000000200000ll
+#define	DRAW_EFIELD			0x0000000000400000ll
+#define	DRAW_HFIELD			0x0000000000800000ll
+#define	DRAW_EHFIELD		0x0000000001000000ll
+#define	DRAW_POYNTING		0x0000000002000000ll
+#define	DRAW_ENABLED		0x0000000004000000ll
+#define	DRAW_QUIT			0x0000000008000000ll
+#define	DRAW_NEWRDPAT		0x0000000010000000ll
+#define	OVERLAY_STRUCT		0x0000000020000000ll
+#define	NEAREH_SNAPSHOT		0x0000000040000000ll
+#define	NEAREH_ANIMATE		0x0000000080000000ll
+#define	ENABLE_RDPAT		0x0000000100000000ll
+#define	ENABLE_NEAREH		0x0000000200000000ll
+#define	DRAW_FLAGS			0x00000000FFE00000ll
 
 /* NEC2 editor flags */
-#define	NEC2_EDIT_SAVE		0x0000000200000000ll /* Save NEC2 editor data to a file */
-#define	NEC2_SAVE			0x0000000400000000ll /* Saving to a NEC2 input file */
+#define	NEC2_EDIT_SAVE		0x0000000400000000ll /* Save NEC2 editor data to a file */
+#define	NEC2_SAVE			0x0000000800000000ll /* Saving to a NEC2 input file */
+/* Structure/rad pattern/freq. plots image save */
+#define	IMAGE_SAVE			0x0000001000000000ll
 
 /* Other flags */
-#define	ERROR_CONDX			0x0000000800000000ll
-#define	INPUT_PENDING		0x0000001000000000ll
-#define	ENABLE_EXCITN		0x0000002000000000ll
+#define	ERROR_CONDX			0x0000002000000000ll
+#define	INPUT_PENDING		0x0000004000000000ll
+#define	ENABLE_EXCITN		0x0000008000000000ll
 
 /* Allocation control flags */
-#define	ALLOC_NEAREH_BUFF	0x0000004000000000ll
-#define	ALLOC_RDPAT_BUFF	0x0000008000000000ll
-#define	ALLOC_PNTING_BUFF	0x0000010000000000ll
+#define	ALLOC_NEAREH_BUFF	0x0000010000000000ll
+#define	ALLOC_RDPAT_BUFF	0x0000020000000000ll
+#define	ALLOC_PNTING_BUFF	0x0000040000000000ll
 
 #define	ALL_FLAGS		    ~0ll
 
@@ -769,6 +769,7 @@ void Gtk_Quit(void);
 void Pass_EH_Flags(void);
 void Alloc_Crnt_Buffs(void);
 void Free_Crnt_Buffs(void);
+void About_Dialog(GtkWidget *aboutdialog);
 /* cmnd_edit.c */
 void Excitation_Command(int action);
 void Frequency_Command(int action);
